# channel2pdf

Export Telegram Channel to PDF

## usage

```
import channel2pdf
channel2pdf.gen(CHANNEL_USERNAME)
```

## how to install

`sudo -v && wget -nv -O- https://download.calibre-ebook.com/linux-installer.sh | sudo sh /dev/stdin` 
`pip3 install channel2pdf`